@@ -25,17 +25,12 @@ Note:
 """
 
 import argparse
-from functools import partial
 from importlib import import_module  # type: ignore
 from typing import List
 
 import yourdfpy  # pylint: disable=import-error
-from yourdfpy.viz import (  # pylint: disable=import-error
-    generate_joint_limit_trajectory,
-    viewer_callback,
-)
 
-from robot_descriptions._description_names import DESCRIPTION_NAMES
+from robot_descriptions._descriptions import DESCRIPTIONS
 
 
 def positive_float(value) -> float:
@@ -109,21 +104,22 @@ def get_argument_parser() -> argparse.ArgumentParser:
         "name",
         help="name of the robot description",
     )
-    parser_animate.add_argument(
-        "--collision",
-        action="store_true",
-        help="use collision geometry for the visualized robot description",
-    )
-    parser_animate.add_argument(
-        "--loop-time",
-        type=positive_float,
-        default=6.0,
-        help="duration of animation loop in seconds",
-    )
 
     return parser
 
 
+def list_descriptions():
+    """
+    List descriptions to the standard output.
+    """
+    for name in sorted(list(DESCRIPTIONS)):
+        desc = DESCRIPTIONS[name]
+        formats = ("URDF" if desc.has_urdf else "") + (
+            "MJCF" if desc.has_mjcf else ""
+        )
+        print(f"- {name} [{formats}]")
+
+
 def show(
     name: str,
     configuration: List[float],
@@ -163,48 +159,28 @@ def show(
     )
 
 
-def animate(
-    name: str,
-    collision: bool,
-    loop_time: float,
-) -> None:
+def animate(name: str) -> None:
     """
-    Load and animate a given robot description.
+    Show how to use yourdfpy to animate a given robot description.
 
     Args:
         name: Name of the robot description.
-        collision: Use collision rather than visualization geometry.
-        loop_time: Animation duration in seconds.
     """
     try:
         module = import_module(f"robot_descriptions.{name}")
     except ModuleNotFoundError:
         module = import_module(f"robot_descriptions.{name}_description")
+
     if not hasattr(module, "URDF_PATH"):
         raise ValueError(
-            "show command only applies to URDF, check out the "
-            "``show_in_mujoco.py`` example for MJCF descriptions"
+            "animation is only available for URDF descriptions, "
+            "check out the ``show_in_mujoco.py`` example for MJCF"
         )
 
-    if collision:
-        robot = yourdfpy.URDF.load(
-            module.URDF_PATH,
-            build_collision_scene_graph=True,
-            load_collision_meshes=True,
-        )
-    else:
-        robot = yourdfpy.URDF.load(module.URDF_PATH)
-
-    robot.show(
-        collision_geometry=collision,
-        callback=partial(
-            viewer_callback,
-            urdf_model=robot,
-            loop_time=loop_time,
-            trajectory=generate_joint_limit_trajectory(
-                urdf_model=robot, loop_time=loop_time
-            ),
-        ),
+    print(
+        "Check out yourdfpy more URDF features like animation or checking "
+        "collision meshes. In this instance, the yourdfpy command is:\n\n"
+        f"\tyourdfpy {module.URDF_PATH} --animate\n"
     )
 
 
@@ -215,10 +191,10 @@ def main(argv=None):
     parser = get_argument_parser()
     args = parser.parse_args(argv)
     if args.subcmd == "list":
-        print("\n".join(DESCRIPTION_NAMES))
+        list_descriptions()
     elif args.subcmd == "show":
         show(args.name, args.configuration, args.collision)
     elif args.subcmd == "animate":
-        animate(args.name, args.collision, args.loop_time)
+        animate(args.name)
     else:  # no subcommand
         parser.print_help()
