@@ -93,17 +93,20 @@ DESCRIPTIONS: Dict[str, Description] = {
     "fetch_description": Description(Format.URDF),
     "finger_edu_description": Description(Format.URDF),
     "gen2_description": Description(Format.URDF),
+    "gen3_mj_description": Description(Format.MJCF),
     "ginger_description": Description(Format.URDF),
     "go1_description": Description(Format.URDF),
     "go1_mj_description": Description(Format.MJCF),
     "hyq_description": Description(Format.URDF),
     "icub_description": Description(Format.URDF),
     "iiwa_description": Description(Format.URDF),
+    "jaxon_description": Description(Format.URDF),
     "jvrc_description": Description(Format.URDF),
     "jvrc_mj_description": Description(Format.MJCF),
     "laikago_description": Description(Format.URDF),
     "mini_cheetah_description": Description(Format.URDF),
     "minitaur_description": Description(Format.URDF),
+    "nextage_description": Description(Format.URDF),
     "panda_description": Description(Format.URDF),
     "panda_mj_description": Description(Format.MJCF),
     "pepper_description": Description(Format.URDF),
